@@ -1,5 +1,7 @@
-from enum import Enum, IntEnum
-from typing import Any, Dict, List
+from enum import IntEnum
+from typing import Any
+from typing import Dict
+from typing import List
 
 try:
     import networkx as nx
