@@ -1,4 +1,6 @@
-from typing import Any, Dict, List
+from typing import Any
+from typing import Dict
+from typing import List
 
 __virtualname__ = "details"
 
