@@ -1,5 +1,7 @@
 from collections import namedtuple
-from typing import Any, Dict, List
+from typing import Any
+from typing import Dict
+from typing import List
 
 __virtualname__ = "simple"
 
