@@ -1,5 +1,7 @@
+from typing import Any
+from typing import Dict
+
 from dict_tools import data as data_
-from typing import Any, Dict
 
 __func_alias__ = {"format_": "format"}
 
