@@ -1,4 +1,7 @@
-from typing import Any, Dict, List
+from typing import Any
+from typing import Dict
+from typing import List
+
 from dict_tools import data as data_
 
 
